@@ -1,11 +1,11 @@
-from django.db.models.signals import pre_save
+from django.db.models.signals import post_save
 from django.dispatch import receiver
 
 from . import utils
 
 
 def track_model(model):
-    @receiver(pre_save, sender=model, weak=False, dispatch_uid='simpleimages')
+    @receiver(post_save, sender=model, weak=False, dispatch_uid='simpleimages')
     def transform_signal(sender, **kwargs):
         utils.perform_transformation(
             [kwargs['instance']],
@@ -13,5 +13,5 @@ def track_model(model):
         )
 
     def disconnect():
-        pre_save.disconnect(sender=model, dispatch_uid='simpleimages')
+        post_save.disconnect(sender=model, dispatch_uid='simpleimages')
     return disconnect
